Bridge between the abstract plugin framework (room-protocol) and the
concrete broker internals (room-cli). This module provides the concrete
ChatWriter and HistoryReader types that implement the
MessageWriter and HistoryAccess traits respectively.
This is the only plugin submodule that imports from crate::broker.
Plugin authors never use these types directly — they receive trait objects
via [CommandContext].
Structs
- Chat
Writer - Short-lived scoped handle for a plugin to write messages to the chat.
- History
Reader - Scoped read-only handle to a room’s chat history.
- Team
Checker - Concrete
TeamAccessbacked by the daemon’sUserRegistry.