Structs
- Help
Plugin - Built-in
/helpplugin. Lists all available commands or shows details for a specific command. Dogfoods the plugin API — usesctx.available_commandsto enumerate the registry without holding a reference to it.
/help plugin. Lists all available commands or shows details
for a specific command. Dogfoods the plugin API — uses
ctx.available_commands to enumerate the registry without holding a
reference to it.